@@ -13,8 +13,7 @@
 ##############################################################################
 """Unit tests for TextIndexWrapper.
 """
-import unittest
-from zope.testing import doctest
+import doctest
 
 def test_suite():
     return doctest.DocFileSuite("../textindex.txt")
